==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/streamtuner/st-category-view.h <==
/*
 * $Id: st-category-view.h,v 1.15 2004/01/29 16:45:04 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_CATEGORY_VIEW_H
#define _ST_CATEGORY_VIEW_H

#include <gtk/gtk.h>
#include "st-browser-tab.h"

#define ST_TYPE_CATEGORY_VIEW			(st_category_view_get_type())
#define ST_CATEGORY_VIEW(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_CATEGORY_VIEW, STCategoryView))
#define ST_CATEGORY_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_CATEGORY_VIEW, STCategoryViewClass))
#define ST_IS_CATEGORY_VIEW(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_CATEGORY_VIEW))
#define ST_IS_CATEGORY_VIEW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_CATEGORY_VIEW))
#define ST_CATEGORY_VIEW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_CATEGORY_VIEW, STCategoryViewClass))

typedef struct
{
  GtkTreeView		view;

  STBrowserTab		*tab;			/* public, the parent tab */
  GtkTreeStore		*store;

  guint			selection_changed_hid;

  GtkCellRenderer	*pixbuf_renderer;
} STCategoryView;

typedef struct
{
  GtkTreeViewClass	parent_class;
} STCategoryViewClass;

GType		st_category_view_get_type	(void);
GtkWidget	*st_category_view_new		(STBrowserTab *tab);

void st_category_view_append_categories		(STCategoryView	*view,
						 GNode		*categories);
void st_category_view_clear			(STCategoryView	*view);

#endif /* _ST_CATEGORY_VIEW_H */

==> streamtuner-0.12.3.tar.gz: streamtuner-0.12.3/src/streamtuner/st-category-view.h <==
/*
 * $Id: st-category-view.h,v 1.24 2004/03/27 21:48:10 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_CATEGORY_VIEW_H
#define _ST_CATEGORY_VIEW_H

#include <gtk/gtk.h>
#include "st-category-bag.h"
#include "st-category-store.h"

#define ST_TYPE_CATEGORY_VIEW			(st_category_view_get_type())
#define ST_CATEGORY_VIEW(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_CATEGORY_VIEW, STCategoryView))
#define ST_CATEGORY_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_CATEGORY_VIEW, STCategoryViewClass))
#define ST_IS_CATEGORY_VIEW(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_CATEGORY_VIEW))
#define ST_IS_CATEGORY_VIEW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_CATEGORY_VIEW))
#define ST_CATEGORY_VIEW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_CATEGORY_VIEW, STCategoryViewClass))

typedef struct _STCategoryViewPrivate STCategoryViewPrivate;

typedef struct
{
  GtkTreeView			view;

  STCategoryViewPrivate		*priv;
} STCategoryView;

typedef struct
{
  GtkTreeViewClass		parent_class;

  /* signals */
  void (*selection_changed) (STCategoryView *view);
} STCategoryViewClass;

GType		st_category_view_get_type	(void);
GtkWidget	*st_category_view_new		(STCategoryStore *store);

#endif /* _ST_CATEGORY_VIEW_H */
